@@ -1,8 +1,8 @@
 #' Estimation of the GB2 distribution from group data
 #'
 #' The function \code{fitgroup.gb2} implements the estimation of the GB2 distribution from group
-#' data in form of income shares using the non-linear least squares (NLS) and the generalised method of
-#' moments (GMM) estimators.
+#' data in form of income shares using the equally weighted minimum distance (EWMD) and the 
+#' optimally weighted minimum distance (OMD) estimators.
 #'
 #' @param y Vector of (non-cumulative) income shares expressed as decimals or percentage.
 #'  At least four data points are required to estimate the parameters of the income distribution.
@@ -11,36 +11,36 @@
 #'  \code{y}.
 #' @param gini.e specifies the survey Gini index expressed as a decimal.
 #' @param pc.inc specifies an estimate of per capita income. If not provided, the weighting matrix
-#'  cannot be computed, hence GMM estimates will not be reported.
-#' @param se.gmm If \code{TRUE} and the argument \code{N} is not \code{NULL}, the standard errors
-#' of the shape parameters of the GMM estimation are computed using results from Beach and Davison(1983) and Hajargasht and
+#'  cannot be computed, hence OMD estimates will not be reported.
+#' @param se.omd If \code{TRUE} and the argument \code{N} is not \code{NULL}, the standard errors
+#' of the shape parameters of the OMD estimates are computed using results from Beach and Davison(1983) and Hajargasht and
 #'  Griffiths (2016).See Jorda et al. (2018) for details. By default, this argument is \code{FALSE}.
 #' @param se.scale If \code{TRUE} and the argument \code{N} is not \code{NULL}, the standard error
-#'  of the scale parameter of the GMM estimation is obtained by Monte Carlo simulation
+#'  of the scale parameter of the OMD estimation is obtained by Monte Carlo simulation
 #'  of random samples of size \code{N}. By default, this argument is \code{FALSE}.
-#' @param se.nls If \code{TRUE} and the argument \code{N} is not \code{NULL}, the standard errors of the NLS parameters
+#' @param se.ewmd If \code{TRUE} and the argument \code{N} is not \code{NULL}, the standard errors of the EWMD estimates
 #' are obtained using Monte Carlo simulation of random samples of size \code{N}. By default, this argument is \code{FALSE}.
 #' @param N Specifies the size of the sample from which the grouped data was generated. This
 #'  information is required to compute the standard errors.
 #' @param nrep Number of samples to be drawn in the Monte Carlo simulation of the standard error of
-#' the NLS parameters and the scale parameter of the GMM estimation.
+#' the EWMD estimates and the scale parameter of the OMD estimation.
 #' @param grid A sequence of positive real numbers to be used as initial values using the
 #' algorithm developed by Jorda et al. (2018).
 #' @param rescale Rescalation factor of per capita income. Reescalation might help to invert
 #' the weight matrix when the scale is too large or too small. The argument \code{rescale} should be
-#' a positive real number which, by default, is set to 1000.
-#' @param gini if \code{TRUE}, reports an estimate of the Gini index using NLS and, if
-#' possible, GMM.
+#' a positive real number which, by default, is set to 1000. The magnitude of this  factor is taken into account in the estimation of the scale parameter, so the provided estimate and its standard error are equivalent to those obtained with \code{rescale = 1}.
+#' @param gini if \code{TRUE}, reports an estimate of the Gini index using the EWMD estimator and, if
+#' possible, the OMD estimator.
 #' @return the function \code{fitgroup.gb2} returns the following objects:
 #'   \itemize{
-#'     \item \code{nls.estimation} Matrix containing the parameters of the GB2 distribution estimated
-#'        by NLS and, if \code{se.nls = TRUE}, their standard errors.
-#'     \item \code{nls.rss} Residual sum of squares of the NLS estimation.
-#'     \item \code{gmm.estimation} Matrix containing the parameters of the GB2 distribution estimated
-#'        by GMM and, if \code{se.gmm = TRUE}, their standard errors.
-#'     \item \code{gmm.rss} Weighted residual sum of squares of the GMM estimation.
+#'     \item \code{ewmd.estimation} Matrix containing the parameters of the GB2 distribution estimated
+#'        by EWMD and, if \code{se.ewmd = TRUE}, their standard errors.
+#'     \item \code{ewmd.rss} Residual sum of squares of the EWMD estimation.
+#'     \item \code{omd.estimation} Matrix containing the parameters of the GB2 distribution estimated
+#'        by OMD and, if \code{se.omd = TRUE}, their standard errors.
+#'     \item \code{omd.rss} Weighted residual sum of squares of the OMD estimation.
 #'     \item \code{gini.estimation} Vector with the survey Gini index and the estimated Gini
-#'      indices using NLS and GMM whenever possible.
+#'      indices using EWMD and OMD estimates whenever possible.
 #'   }
 #' @details The Generalised Beta of the Second Kind (GB2) is a general class of distributions that is
 #' acknowledged to provide an accurate fit to income data (McDonald 1984; McDonald and Mantrala,1995).
@@ -58,7 +58,7 @@
 #' including The World Income Inequality Database (UNU-WIDER, 2017), PovcalNet (World Bank, 2018) or the World Wealth
 #' and Income Database (Alvaredo et al., 2018).
 #'
-#' For NLS, numerical optimisation is achieved using the Levenberg-Marquardt Algorithm via \code{\link[minpack.lm]{nlsLM}}
+#' For EWMD, numerical optimisation is achieved using the Levenberg-Marquardt Algorithm via \code{\link[minpack.lm]{nlsLM}}
 #' Conventionally, moment estimates of a restricted model are taken as initial values. A potential
 #' limitation of this method is that, as the dimensionality of the parameter
 #' space increases, it is more difficult to achieve global convergence. Although it seems quite intuitive that the moment
@@ -79,20 +79,20 @@
 #' This method, however, does not provide
 #' an estimate for the scale parameter because the Lorenz curve is independent to scale. The scale
 #' parameter is estimated by equating the sample mean, specified by \code{pc.inc}, to the population
-#' mean of the GB2 distribution. Because NLS does not use the optimal
+#' mean of the GB2 distribution. Because EWMD does not use the optimal
 #' covariance matrix of the moment conditions, the standard errors of the parameters
 #' are obtained by Monte Carlo simulation. Please be aware that the estimation of the standard errors
 #' might take a long time, especially if the sample size is large.
 #'
-#' \code{fitgroup.gb2} also implements a two-stage GMM estimator. In the first stage, NLS estimates
+#' \code{fitgroup.gb2} also implements a two-stage OMD estimator. In the first stage, EWMD estimates
 #' are obtained as described above, which are used to compute a first stage estimator
 #' of the weighting matrix. The weighting matrix is used in the second stage to obtain optimally
 #' weighted estimates of the parameters. The numerical optimisation is performed using
 #' \code{\link{optim}} with the BFGS method. If \code{optim} reports an error, the L-BFGS method
-#' is used. NLS estimates are used as initial values for the optimisation algorithm. The GMM estimation
+#' is used. EWMD estimates are used as initial values for the optimisation algorithm. The OMD estimation
 #'  incorporates the optimal weight matrix, thus making possible to derive the asymptotic standard
 #'  errors of the parameters using results from Beach and Davison(1983) and Hajargasht and
-#'  Griffiths (2016). As in the NLS estimation, the scale parameter is obtained by matching the
+#'  Griffiths (2016). As in the EWMD estimation, the scale parameter is obtained by matching the
 #'  population mean of the GB2 distribution to the sample mean. Hence, the standard error of the scale
 #'  parameter is estimated by Monte Carlo simulation.
 #'
@@ -103,7 +103,6 @@
 #'
 #' @references
 #'  Alvaredo, F., A. Atkinson, T. Piketty, E. Saez, and G. Zucman. The World Wealth and Income Database.
-#'  \url{http://www.wid.world}.
 #'
 #' Beach, C.M. and R. Davidson (1983): Distribution-free statistical inference with
 #' Lorenz curves and income shares, \emph{The Review of Economic Studies}, 50, 723 - 735.
@@ -121,7 +120,6 @@
 #'  \emph{Journal of Applied Econometrics}, 10, 201 - 204.
 #'
 #'  UNU-WIDER (2018). World Income Inequality Database (WIID3.4).
-#'  \url{https://www.wider.unu.edu/project/wiid-world-income-inequality-database}.
 #'
 #'  World Bank (2018). PovcalNet Data Base. Washington, DC: World Bank. \url{http://iresearch.worldbank.org/PovcalNet/home.aspx}.
 #'
@@ -132,7 +130,7 @@
 #' @importFrom minpack.lm nlsLM nls.lm.control
 #' @importFrom stats resid coef uniroot optim
 #' @export
-fitgroup.gb2 <- function(y, x = rep(1 / length(y), length(y)), gini.e, pc.inc = NULL, se.gmm = FALSE, se.nls = FALSE, se.scale = FALSE, N = NULL, nrep = 10^3, grid = 1:20, rescale = 1000, gini = FALSE) {
+fitgroup.gb2 <- function(y, x = rep(1 / length(y), length(y)), gini.e, pc.inc = NULL, se.omd = FALSE, se.ewmd = FALSE, se.scale = FALSE, N = NULL, nrep = 10^3, grid = 1:20, rescale = 1000, gini = FALSE) {
   if(length(y) != length(x)) {
     stop("x and y must be of the same length")
   }
@@ -290,18 +288,18 @@ fitgroup.gb2 <- function(y, x = rep(1 / length(y), length(y)), gini.e, pc.inc =
   nls.q <- par.q[rg]
   if(nls.q <= 1 / nls.a) {
     temp.b <- NA
-    print("Unable to compute the scale parameter and the GMM estimation. Condition for the existence of the first moment violated: q <= 1 / a")
+    print("Unable to compute the scale parameter and the OMD estimation. Condition for the existence of the first moment violated: q <= 1 / a")
   }
   if(is.null(pc.inc)) {
     temp.b <- NA
-    print("Unable to compute the scale parameter and the GMM estimation. Per capita GDP not provided")
+    print("Unable to compute the scale parameter and the OMD estimation. Per capita GDP not provided")
   }
   if(!is.null(pc.inc) & (nls.q > 1 / nls.a)) {
     incpc <- pc.inc / rescale
     temp.b <- scale.gb2(c(nls.a, nls.p, nls.q), incpc)
   }
   if(nls.q <= 2 / nls.a){
-    print("Unable to compute GMM estimates of the parameters. Condition for the existence of the second moment violated: q <= 2 / a")
+    print("Unable to compute OMD estimates of the parameters. Condition for the existence of the second moment violated: q <= 2 / a")
   }
   if(nls.q <= 2 / nls.a | is.na(temp.b)) {
     gmm.coef <- matrix(NA, 1, 4)
@@ -311,7 +309,7 @@ fitgroup.gb2 <- function(y, x = rep(1 / length(y), length(y)), gini.e, pc.inc =
   else {
     regress <- try(opt.gmm.gb2(cprob, share, init.est = c(nls.a, temp.b, nls.p, nls.q), cons.est = c(nls.a, temp.b, nls.p, nls.q)))
     if('try-error'%in%class(regress$opt1)) {
-      print("Unable to compute GMM estimates of the parameters. The weight martrix cannot be inverted. Try changing the value of rescale")
+      print("Unable to compute OMD estimates of the parameters. The weight martrix cannot be inverted. Try changing the value of rescale")
       gmm.coef <- matrix(NA, 1, 4)
       gmm.se <- matrix(NA, 1, 4)
       gmm.rss <- NA
@@ -319,23 +317,23 @@ fitgroup.gb2 <- function(y, x = rep(1 / length(y), length(y)), gini.e, pc.inc =
     else {
       gmm.rss <- regress$opt1$value
       gmm.coef <- regress$opt1$par
-      gmm.coef[2] <- scale.gb2(c(gmm.coef[1], gmm.coef[3], gmm.coef[4]), incpc)
+      gmm.coef[2] <- scale.gb2(c(gmm.coef[1], gmm.coef[3], gmm.coef[4]), pc.inc)
       gmm.se <- matrix(NA, 1, 4)
     }
   }
   nls.estimation <- matrix(NA, 2, 4)
-  nls.coef <- matrix(c(nls.a, temp.b, nls.p, nls.q), 1, 4)
+  nls.coef <- matrix(c(nls.a, temp.b * rescale, nls.p, nls.q), 1, 4)
   nls.se <- matrix(NA, 1, 4)
 
-  if (se.nls == TRUE) {
+  if (se.ewmd == TRUE) {
     if (is.null(N)) {
       print("Unable to compute the standard errors. Please provide the sample size")
     }
     else {
-      se.calc <- simsd.gb2(x = x, theta = nls.coef, N = N, nrep = nrep, se.scale = se.scale)
+      se.calc <- simsd.gb2(x = x, theta = nls.coef, N = N, nrep = nrep, se.scale = se.scale, factor.r = rescale)
       nls.se <- se.calc$nls.se
       if(!is.na(temp.b)) {
-        if(se.gmm == TRUE){
+        if(se.omd == TRUE){
           gmm.se <- gmmse.gb2(gmm.coef, cprob, N)
         }
         if(se.scale == TRUE){
@@ -344,7 +342,7 @@ fitgroup.gb2 <- function(y, x = rep(1 / length(y), length(y)), gini.e, pc.inc =
       }
     }
   }
-  if (se.nls == FALSE & se.gmm == TRUE) {
+  if (se.ewmd == FALSE & se.omd == TRUE) {
     if (is.null(N)) {
       print("Unable to compute the standard errors. Please provide the sample size")
     }
@@ -352,7 +350,7 @@ fitgroup.gb2 <- function(y, x = rep(1 / length(y), length(y)), gini.e, pc.inc =
       if(!is.na(temp.b)) {
         gmm.se <- gmmse.gb2(gmm.coef, cprob, N)
         if(se.scale == TRUE){
-          gmm.se[2] <- simsd.gb2(x = x, theta = nls.coef, N = N, nrep = nrep, se.scale = se.scale)$sd.scale
+          gmm.se[2] <- simsd.gb2(x = x, theta = nls.coef, N = N, nrep = nrep, se.scale = se.scale, factor.r = rescale)$sd.scale
         }
       }
     }
@@ -378,15 +376,15 @@ fitgroup.gb2 <- function(y, x = rep(1 / length(y), length(y)), gini.e, pc.inc =
     else {gmm.gini <- NA}
     nls.gini <- simgini.gb2(nls.coef)
     gini.estimation <- matrix(NA, 1, 3)
-    colnames(gini.estimation) <- c("Survey", "NLS estimate", "GMM estimate")
+    colnames(gini.estimation) <- c("Survey", "EWMD estimate", "OMD estimate")
     gini.estimation[1] <- gini.e
     gini.estimation[2] <- nls.gini
     gini.estimation[3] <- gmm.gini
-    out2 <- list(grouped.data = grouped.data, distribution = "GB2", nls.estimation = nls.estimation, nls.rss = nls.rss, gmm.estimation = gmm.estimation, gmm.rss = gmm.rss,
+    out2 <- list(grouped.data = grouped.data, distribution = "GB2", ewmd.estimation = nls.estimation, ewmd.rss = nls.rss, omd.estimation = gmm.estimation, omd.rss = gmm.rss,
       gini.estimation = gini.estimation)
   }
   else {
-    out2 <- list(grouped.data = grouped.data, distribution = "GB2", nls.estimation = nls.estimation, nls.rss = nls.rss, gmm.estimation = gmm.estimation, gmm.rss = gmm.rss)
+    out2 <- list(grouped.data = grouped.data, distribution = "GB2", ewmd.estimation = nls.estimation, ewmd.rss = nls.rss, omd.estimation = gmm.estimation, omd.rss = gmm.rss)
   }
   return(out2)
 }
